==> nextcloud-32.0.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/encryption/l10n/ar.js <==
OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "لم يُمكن العثور على كلمة مرور مفتاح الاستعادة",
    "Please repeat the recovery key password" : "يرجى تكرار كلمة مرور مفتاح الاستعادة",
    "Repeated recovery key password does not match the provided recovery key password" : "كلمة مرور مفتاح الاستعادة المُكرّرة لا تتطابق مع كلمة مرور مفتاح الاستعادة المُدخلة",
    "Recovery key successfully enabled" : "تمّ بنجاح تفعيل مفتاح الاستعادة",
    "Could not enable recovery key. Please check your recovery key password!" : "لم يُمكن تفعيل مفتاح الاستعادة. يرجى التحقق من كلمة مرور مفتاح الاستعادة!",
    "Recovery key successfully disabled" : "تمّ بنجاح تعطيل مفتاح الاستعادة ",
    "Could not disable recovery key. Please check your recovery key password!" : "لم يُمكن تعطيل مفتاح الاستعادة. يرجى التحقق من كلمة مرور مفتاح الاستعادة!",
    "Missing parameters" : "المعاملات ناقصة",
    "Please provide the old recovery password" : "يرجى إعطاء كلمة مرور الاستعادة القديمة",
    "Please provide a new recovery password" : "يرجى إعطاء كلمة مرور جديدة للاستعادة",
    "Please repeat the new recovery password" : "يرجى تكرار كلمة مرور الاستعادة الجديدة",
    "Password successfully changed." : "تمّ بنجاح تغيير كلمة المرور.",
    "Could not change the password. Maybe the old password was not correct." : "تعذر تغيير كلمة المرور. يُمكن أن تكون كلمة المرور القديمة غير صحيحة.",
    "Recovery Key disabled" : "مفتاح الاستعادة مُعطّل",
    "Recovery Key enabled" : "تمّ تمكين مفتاح الاستعادة",
    "Could not enable the recovery key, please try again or contact your administrator" : "تعذر تمكين مفتاح الاسترداد ، يرجى المحاولة مرة أخرى أو الاتصال بالمسؤول",
    "Could not update the private key password." : "تعذّر تحديث كلمة مرور المفتاح الخاص.",
    "The old password was not correct, please try again." : "كلمة المرور القديمة غير صحيحة ، يرجى المحاولة مرة أخرى.",
    "The current log-in password was not correct, please try again." : "كلمة المرور الحالية للدخول غير صحيحة، يرجى المحاولة مرة أخرى.",
    "Private key password successfully updated." : "تم تحديث كلمة المرور للمفتاح الخاص بنجاح.",
    "Invalid private key for encryption app. Please update your private key password in your personal settings to recover access to your encrypted files." : "مفتاح خاص غير صالح لتطبيق التشفير. يرجى تحديث كلمة مرور المفتاح الخاص في إعداداتك الشخصية لاستعادة الوصول إلى ملفاتك المشفرة.",
    "Encryption App is enabled, but your keys are not initialized. Please log-out and log-in again." : "تم تمكين تطبيق التشفير، ولكن لم تتم تهيئة المفاتيح الخاصة بك. يرجى تسجيل الخروج ثم تسجيل الدخول من جديد.",
    "Please enable server side encryption in the admin settings in order to use the encryption module." : "يرجى تمكين التشفير من جانب الخادم في إعدادات المدير حتى يمكن استخدام وحدة التشفير.",
    "Encryption app is enabled and ready" : "تطبيق التشفير مُفعّل و جاهز للعمل",
    "Bad Signature" : "توقيع غير مقبول",
    "Missing Signature" : "توقيع مفقود",
    "one-time password for server-side-encryption" : "كلمة مرور لمرة واحدة للتشفير من جانب الخادم",
    "Encryption password" : "كلمة مرور التشفير",
    "The administration enabled server-side-encryption. Your files were encrypted using the password <strong>%s</strong>." : "قام المدير بتمكين التشفير من جانب الخادم. و تمّ تشفير ملفاتك باستخدام كلمة المرور <strong>%s</strong>.",
    "The administration enabled server-side-encryption. Your files were encrypted using the password \"%s\"." : "قام المدير بتمكين التشفير من جانب الخادم. و تمّ تشفير ملفاتك باستخدام كلمة المرور \"%s\".",
    "Please login to the web interface, go to the \"Security\" section of your personal settings and update your encryption password by entering this password into the \"Old login password\" field and your current login password." : "يرجى تسجيل الدخول إلى واجهة الويب، و الانتقال إلى قسم \"الأمان\" Security في إعداداتك الشخصية وتحديث كلمة مرور التشفير الخاصة بك عن طريق إدخال كلمة المرور هذه في حقل \"كلمة مرور تسجيل الدخول القديمة\" Old login password،و كلمة مرور تسجيل الدخول الحالية.",
    "Cannot decrypt this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "تعذّر فك تشفير هذا الملف؛ ربما يكون ملفّاً مُشتركاً. رجاءً، أطلب من مالك الملف إلغاء مشاركته معك.",
    "Cannot read this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "تعذرت قراءة هذا الملف؛ ربما يكون ملفّاً مُشتركاً. رجاءً، أطلب من مالك الملف إلغاء مشاركته معك.",
    "Default encryption module" : "وحدة التشفير الافتراضية",
    "Encryption app is enabled but your keys are not initialized, please log-out and log-in again" : "تم تمكين تطبيق التشفير، ولكن لم تتم تهيئة المفاتيح الخاصة بك. يرجى تسجيل الخروج ثم تسجيل الدخول من جديد.",
    "Encrypt the home storage" : "تشفير وحدة التخزين الأساسية",
    "Enabling this option encrypts all files stored on the main storage, otherwise only files on external storage will be encrypted" : "يؤدي تمكين هذا الخيار إلى تشفير جميع الملفات المخزنة على وحدة التخزين الرئيسية، وإلا فسيتم تشفير الملفات الموجودة على وحدة التخزين الخارجية فقط",
    "Enable recovery key" : "تمكين مفتاح الاستعادة",
    "Disable recovery key" : "تعطيل مفتاح الاستعادة",
    "The recovery key is an additional encryption key used to encrypt files. It is used to recover files from an account if the password is forgotten." : "مفتاح الاسترداد هو مفتاح تشفير إضافي يستخدم لتشفير الملفات. يتم استخدامه لاستعادة الملفات من الحساب في حالة نسيان كلمة المرور.",
    "Recovery key password" : "استعادة كلمة مرور المفتاح",
    "Repeat recovery key password" : "أعد كتابة كلمة مرور مفتاح الاستعادة",
    "Change recovery key password:" : "تعديل كلمة المرور استعادة المفتاح:",
    "Old recovery key password" : "كلمة مرور مفتاح الاستعادة القديمة",
    "New recovery key password" : "كلمة مرور جديدة لمفتاح الاستعادة",
    "Repeat new recovery key password" : "أعد كتابة كلمة مرور مفتاح الاستعادة الجديدة",
    "Change Password" : "تعديل كلمة المرور",
    "Basic encryption module" : "وحدة التشفير الأساسية",
    "Your private key password no longer matches your log-in password." : "لم تعد كلمة مرور المفتاح الخاص تطابق كلمة مرور تسجيل الدخول الخاصة بك.",
    "Set your old private key password to your current log-in password:" : "قم بتعيين كلمة مرور المفتاح الخاص القديم على كلمة مرور تسجيل الدخول الحالية:",
    "If you do not remember your old password you can ask your administrator to recover your files." : "إذا كنت لا تتذكر كلمة مرورك القديمة، فيمكنك أن تطلب من المشرف استرداد ملفاتك.",
    "Old log-in password" : "كلمة المرور القديمة الخاصة بالدخول",
    "Current log-in password" : "كلمة المرور الحالية الخاصة بالدخول",
    "Update Private Key Password" : "تحديث كلمة المرور لـ المفتاح الخاص",
    "Enable password recovery:" : "تفعيل استعادة كلمة المرور:",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "تفعيل هذا الخيار يمكنك من اعادة الوصول الى ملفاتك المشفرة عند فقدان كلمة المرور",
    "Enabled" : "مفعلة",
    "Disabled" : "معطلة",
    "Default encryption module for server-side encryption" : "وحدة التشفير الافتراضية للتشفير من جانب الخادم",
    "In order to use this encryption module you need to enable server-side encryption in the admin settings. Once enabled this module will encrypt all your files transparently. The encryption is based on AES 256 keys.\nThe module will not touch existing files, only new files will be encrypted after server-side encryption was enabled. It is also not possible to disable the encryption again and switch back to an unencrypted system.\nPlease read the documentation to know all implications before you decide to enable server-side encryption." : "لاستخدام وحدة التشفير هذه ، تحتاج إلى تمكين التشفير من جانب الخادم في إعدادات المدير. بمجرد تمكين هذه الوحدة ، ستقوم بتشفير جميع ملفاتك بشفافية. يعتمد التشفير على مفاتيح AES 256. لن تلمس الوحدة الملفات الموجودة ، سيتم تشفير الملفات الجديدة فقط بعد تمكين التشفير من جانب الخادم. لكن لاحظ أنه لن يُمكن تعطيل التشفير والعودة إلى حالة عدم التشفير. يرجى قراءة الوثائق لمعرفة جميع العواقب قبل أن تقرر تمكين التشفير من جانب الخادم."
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");

==> nextcloud-32.0.5-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/encryption/l10n/ar.js <==
OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "لم يُمكن العثور على كلمة مرور مفتاح الاستعادة",
    "Please repeat the recovery key password" : "يرجى تكرار كلمة مرور مفتاح الاستعادة",
    "Repeated recovery key password does not match the provided recovery key password" : "كلمة مرور مفتاح الاستعادة المُكرّرة لا تتطابق مع كلمة مرور مفتاح الاستعادة المُدخلة",
    "Recovery key successfully enabled" : "تمّ بنجاح تفعيل مفتاح الاستعادة",
    "Could not enable recovery key. Please check your recovery key password!" : "لم يُمكن تفعيل مفتاح الاستعادة. يرجى التحقق من كلمة مرور مفتاح الاستعادة!",
    "Recovery key successfully disabled" : "تمّ بنجاح تعطيل مفتاح الاستعادة ",
    "Could not disable recovery key. Please check your recovery key password!" : "لم يُمكن تعطيل مفتاح الاستعادة. يرجى التحقق من كلمة مرور مفتاح الاستعادة!",
    "Please provide the old recovery password" : "يرجى إعطاء كلمة مرور الاستعادة القديمة",
    "Please provide a new recovery password" : "يرجى إعطاء كلمة مرور جديدة للاستعادة",
    "Please repeat the new recovery password" : "يرجى تكرار كلمة مرور الاستعادة الجديدة",
    "Password successfully changed." : "تمّ بنجاح تغيير كلمة المرور.",
    "Could not change the password. Maybe the old password was not correct." : "تعذر تغيير كلمة المرور. يُمكن أن تكون كلمة المرور القديمة غير صحيحة.",
    "Recovery Key disabled" : "مفتاح الاستعادة مُعطّل",
    "Recovery Key enabled" : "تمّ تمكين مفتاح الاستعادة",
    "Could not enable the recovery key, please try again or contact your administrator" : "تعذر تمكين مفتاح الاسترداد ، يرجى المحاولة مرة أخرى أو الاتصال بالمسؤول",
    "Could not update the private key password." : "تعذّر تحديث كلمة مرور المفتاح الخاص.",
    "The old password was not correct, please try again." : "كلمة المرور القديمة غير صحيحة ، يرجى المحاولة مرة أخرى.",
    "The current log-in password was not correct, please try again." : "كلمة المرور الحالية للدخول غير صحيحة، يرجى المحاولة مرة أخرى.",
    "Private key password successfully updated." : "تم تحديث كلمة المرور للمفتاح الخاص بنجاح.",
    "Invalid private key for encryption app. Please update your private key password in your personal settings to recover access to your encrypted files." : "مفتاح خاص غير صالح لتطبيق التشفير. يرجى تحديث كلمة مرور المفتاح الخاص في إعداداتك الشخصية لاستعادة الوصول إلى ملفاتك المشفرة.",
    "Encryption App is enabled, but your keys are not initialized. Please log-out and log-in again." : "تم تمكين تطبيق التشفير، ولكن لم تتم تهيئة المفاتيح الخاصة بك. يرجى تسجيل الخروج ثم تسجيل الدخول من جديد.",
    "Please enable server side encryption in the admin settings in order to use the encryption module." : "يرجى تمكين التشفير من جانب الخادم في إعدادات المدير حتى يمكن استخدام وحدة التشفير.",
    "Encryption app is enabled and ready" : "تطبيق التشفير مُفعّل و جاهز للعمل",
    "Bad Signature" : "توقيع غير مقبول",
    "Missing Signature" : "توقيع مفقود",
    "one-time password for server-side-encryption" : "كلمة مرور لمرة واحدة للتشفير من جانب الخادم",
    "Encryption password" : "كلمة مرور التشفير",
    "The administration enabled server-side-encryption. Your files were encrypted using the password <strong>%s</strong>." : "قام المدير بتمكين التشفير من جانب الخادم. و تمّ تشفير ملفاتك باستخدام كلمة المرور <strong>%s</strong>.",
    "The administration enabled server-side-encryption. Your files were encrypted using the password \"%s\"." : "قام المدير بتمكين التشفير من جانب الخادم. و تمّ تشفير ملفاتك باستخدام كلمة المرور \"%s\".",
    "Please login to the web interface, go to the \"Security\" section of your personal settings and update your encryption password by entering this password into the \"Old login password\" field and your current login password." : "يرجى تسجيل الدخول إلى واجهة الويب، و الانتقال إلى قسم \"الأمان\" Security في إعداداتك الشخصية وتحديث كلمة مرور التشفير الخاصة بك عن طريق إدخال كلمة المرور هذه في حقل \"كلمة مرور تسجيل الدخول القديمة\" Old login password،و كلمة مرور تسجيل الدخول الحالية.",
    "Cannot decrypt this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "تعذّر فك تشفير هذا الملف؛ ربما يكون ملفّاً مُشتركاً. رجاءً، أطلب من مالك الملف إلغاء مشاركته معك.",
    "Cannot read this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "تعذرت قراءة هذا الملف؛ ربما يكون ملفّاً مُشتركاً. رجاءً، أطلب من مالك الملف إلغاء مشاركته معك.",
    "Enabling this option encrypts all files stored on the main storage, otherwise only files on external storage will be encrypted" : "يؤدي تمكين هذا الخيار إلى تشفير جميع الملفات المخزنة على وحدة التخزين الرئيسية، وإلا فسيتم تشفير الملفات الموجودة على وحدة التخزين الخارجية فقط",
    "Encrypt the home storage" : "تشفير وحدة التخزين الأساسية",
    "Disable recovery key" : "تعطيل مفتاح الاستعادة",
    "Enable recovery key" : "تمكين مفتاح الاستعادة",
    "The recovery key is an additional encryption key used to encrypt files. It is used to recover files from an account if the password is forgotten." : "مفتاح الاسترداد هو مفتاح تشفير إضافي يستخدم لتشفير الملفات. يتم استخدامه لاستعادة الملفات من الحساب في حالة نسيان كلمة المرور.",
    "Recovery key password" : "استعادة كلمة مرور المفتاح",
    "Repeat recovery key password" : "أعد كتابة كلمة مرور مفتاح الاستعادة",
    "Old recovery key password" : "كلمة مرور مفتاح الاستعادة القديمة",
    "New recovery key password" : "كلمة مرور جديدة لمفتاح الاستعادة",
    "Repeat new recovery key password" : "أعد كتابة كلمة مرور مفتاح الاستعادة الجديدة",
    "If you do not remember your old password you can ask your administrator to recover your files." : "إذا كنت لا تتذكر كلمة مرورك القديمة، فيمكنك أن تطلب من المشرف استرداد ملفاتك.",
    "Old log-in password" : "كلمة المرور القديمة الخاصة بالدخول",
    "Current log-in password" : "كلمة المرور الحالية الخاصة بالدخول",
    "Update" : "تحديث",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "تفعيل هذا الخيار يمكنك من اعادة الوصول الى ملفاتك المشفرة عند فقدان كلمة المرور",
    "Default encryption module" : "وحدة التشفير الافتراضية",
    "Encryption app is enabled but your keys are not initialized, please log-out and log-in again" : "تم تمكين تطبيق التشفير، ولكن لم تتم تهيئة المفاتيح الخاصة بك. يرجى تسجيل الخروج ثم تسجيل الدخول من جديد.",
    "Basic encryption module" : "وحدة التشفير الأساسية",
    "Missing parameters" : "المعاملات ناقصة",
    "Default encryption module for server-side encryption" : "وحدة التشفير الافتراضية للتشفير من جانب الخادم",
    "In order to use this encryption module you need to enable server-side encryption in the admin settings. Once enabled this module will encrypt all your files transparently. The encryption is based on AES 256 keys.\nThe module will not touch existing files, only new files will be encrypted after server-side encryption was enabled. It is also not possible to disable the encryption again and switch back to an unencrypted system.\nPlease read the documentation to know all implications before you decide to enable server-side encryption." : "لاستخدام وحدة التشفير هذه ، تحتاج إلى تمكين التشفير من جانب الخادم في إعدادات المدير. بمجرد تمكين هذه الوحدة ، ستقوم بتشفير جميع ملفاتك بشفافية. يعتمد التشفير على مفاتيح AES 256. لن تلمس الوحدة الملفات الموجودة ، سيتم تشفير الملفات الجديدة فقط بعد تمكين التشفير من جانب الخادم. لكن لاحظ أنه لن يُمكن تعطيل التشفير والعودة إلى حالة عدم التشفير. يرجى قراءة الوثائق لمعرفة جميع العواقب قبل أن تقرر تمكين التشفير من جانب الخادم.",
    "Change recovery key password:" : "تعديل كلمة المرور استعادة المفتاح:",
    "Change Password" : "تعديل كلمة المرور",
    "Your private key password no longer matches your log-in password." : "لم تعد كلمة مرور المفتاح الخاص تطابق كلمة مرور تسجيل الدخول الخاصة بك.",
    "Set your old private key password to your current log-in password:" : "قم بتعيين كلمة مرور المفتاح الخاص القديم على كلمة مرور تسجيل الدخول الحالية:",
    "Update Private Key Password" : "تحديث كلمة المرور لـ المفتاح الخاص",
    "Enable password recovery:" : "تفعيل استعادة كلمة المرور:",
    "Enabled" : "مفعلة",
    "Disabled" : "معطلة"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
